#vboxNpdPanel {
    background-color: #353535;
}

#tglBtn{
    background: #353535;
    color: #f7f7f7;
    border: none;
}

#tglBtn:checked {
    background: #f7f7f7;
    font-weight: bolder;
    color: #353535;
    border: none;
    border-radius: 1px;
}

#lbl{
    color: #303d41;
}

#lblhead{
    color: #303d41;
    font-family: 'Exo 2';
    font-size: 20px;
    font-weight: 800;
    font-variant: normal;
}

#buttons {
    color: #303d41;
    background: #f7f7f7;
}
#buttons:hover { background: #d6d6d6; }
#buttons:active { background: #adadad; }

#lic text{
    background-color: #f7f7f7;
    color: #303d41;
    border: 1px;
    border-color: #303d41;
}

#fin text{
    background-color: #f7f7f7;
    color: #303d41;
    border: 1px;
    border-color: #303d41;
}

#fin{
    font-family: 'Exo 2';
    font-size: 20px;
    font-variant: normal;
}

#ntbkMain{
    background: #f7f7f7;
}

.combo{
    background: #e9e9e9;
    color: #303d41;
    border-radius: 1px;
    border-color: #536064;
}

#entry{
    background: #e9e9e9;
    color: #303d41;
    border-radius: 1px;
    border-color: #536064;
}


#tggl{
    color: #303d41;
}

#prgrssBar text{
    color: #303d41;
}

/* #imgMap{
    background-image: url("/usr/share/ubinstall/images/map-time-zine.svg");
    background-size: cover;
    background-repeat: no-repeat;
} */